==> binnie-mods-1.12-2.2.0.6-sources.jar: binnie/core/machines/errors/ErrorState.java <==
package binnie.core.machines.errors;

import net.minecraft.nbt.NBTTagCompound;

import forestry.api.core.INbtReadable;
import forestry.api.core.INbtWritable;

public class ErrorState implements INbtReadable, INbtWritable {
	/*private String name;
	private String desc;*/
	private IErrorStateDefinition nameDefinition;
	private IErrorStateDefinition definition;
	private int[] data;
	private boolean itemError;
	private boolean tankError;
	private boolean powerError;

	public ErrorState(IErrorStateDefinition definition) {
		this(definition, definition);
	}

	public ErrorState(IErrorStateDefinition definition, int[] data) {
		this(definition, definition, data);
	}

	public ErrorState(IErrorStateDefinition definition, int data) {
		this(definition, definition, new int[]{data});
	}

	public ErrorState(IErrorStateDefinition nameDefinition, IErrorStateDefinition definition) {
		this(nameDefinition, definition, new int[0]);
	}

	public ErrorState(IErrorStateDefinition nameDefinition, IErrorStateDefinition definition, int[] data) {
		EnumErrorType type = definition.getType();
		this.data = data;
		this.itemError = type.isItemError();
		this.tankError = type.isTankError();
		this.powerError = type.isPowerError();
		this.nameDefinition = nameDefinition;
		this.definition = definition;
	}

	public ErrorState(NBTTagCompound nbtTagCompound) {
		this.data = new int[0];
		this.itemError = false;
		this.tankError = false;
		this.powerError = false;
		this.definition = CoreErrorCode.UNKNOWN;
		this.nameDefinition = CoreErrorCode.UNKNOWN;
		readFromNBT(nbtTagCompound);
	}

	@Override
	public String toString() {
		return nameDefinition.getName();
	}

	public String getTooltip() {
		return definition.getDescription();
	}

	public int[] getData() {
		return this.data;
	}

	@Override
	public void readFromNBT(final NBTTagCompound nbt) {
		this.nameDefinition = ErrorStateRegistry.getErrorState(nbt.func_74779_i("name"));
		this.definition = ErrorStateRegistry.getErrorState(nbt.func_74779_i("desc"));
		this.data = nbt.func_74759_k("data");
		this.itemError = nbt.func_74767_n("item");
		this.tankError = nbt.func_74767_n("tank");
		this.powerError = nbt.func_74767_n("power");
	}

	@Override
	public NBTTagCompound writeToNBT(final NBTTagCompound nbt) {
		nbt.func_74778_a("name", nameDefinition.getUID());
		nbt.func_74778_a("desc", definition.getUID());
		nbt.func_74783_a("data", this.data);
		if (this.isItemError()) {
			nbt.func_74757_a("item", true);
		}
		if (this.isTankError()) {
			nbt.func_74757_a("tank", true);
		}
		if (this.isPowerError()) {
			nbt.func_74757_a("power", true);
		}
		return nbt;
	}

	public boolean isItemError() {
		return this.itemError;
	}

	public boolean isTankError() {
		return this.tankError;
	}

	public boolean isPowerError() {
		return this.powerError;
	}
}

==> binnie-mods-1.12.2-2.4.0.78-sources.jar: binnie/core/machines/errors/ErrorState.java <==
package binnie.core.machines.errors;

import net.minecraft.nbt.NBTTagCompound;

import forestry.api.core.INbtReadable;
import forestry.api.core.INbtWritable;

public class ErrorState implements INbtReadable, INbtWritable {
	/*private String name;
	private String desc;*/
	private IErrorStateDefinition nameDefinition;
	private IErrorStateDefinition definition;
	private int[] data;
	private boolean itemError;
	private boolean tankError;
	private boolean powerError;

	public ErrorState(IErrorStateDefinition definition) {
		this(definition, definition);
	}

	public ErrorState(IErrorStateDefinition definition, int[] data) {
		this(definition, definition, data);
	}

	public ErrorState(IErrorStateDefinition definition, int data) {
		this(definition, definition, new int[]{data});
	}

	public ErrorState(IErrorStateDefinition nameDefinition, IErrorStateDefinition definition) {
		this(nameDefinition, definition, new int[0]);
	}

	public ErrorState(IErrorStateDefinition nameDefinition, IErrorStateDefinition definition, int[] data) {
		EnumErrorType type = definition.getType();
		this.data = data;
		this.itemError = type.isItemError();
		this.tankError = type.isTankError();
		this.powerError = type.isPowerError();
		this.nameDefinition = nameDefinition;
		this.definition = definition;
	}

	public ErrorState(NBTTagCompound nbtTagCompound) {
		this.data = new int[0];
		this.itemError = false;
		this.tankError = false;
		this.powerError = false;
		this.definition = CoreErrorCode.UNKNOWN;
		this.nameDefinition = CoreErrorCode.UNKNOWN;
		readFromNBT(nbtTagCompound);
	}

	@Override
	public String toString() {
		return nameDefinition.getName();
	}

	public String getTooltip() {
		return definition.getDescription();
	}

	public int[] getData() {
		return this.data;
	}

	@Override
	public void readFromNBT(final NBTTagCompound nbt) {
		this.nameDefinition = ErrorStateRegistry.getErrorState(nbt.getString("name"));
		this.definition = ErrorStateRegistry.getErrorState(nbt.getString("desc"));
		this.data = nbt.getIntArray("data");
		this.itemError = nbt.getBoolean("item");
		this.tankError = nbt.getBoolean("tank");
		this.powerError = nbt.getBoolean("power");
	}

	@Override
	public NBTTagCompound writeToNBT(final NBTTagCompound nbt) {
		nbt.setString("name", nameDefinition.getUID());
		nbt.setString("desc", definition.getUID());
		nbt.setIntArray("data", this.data);
		if (this.isItemError()) {
			nbt.setBoolean("item", true);
		}
		if (this.isTankError()) {
			nbt.setBoolean("tank", true);
		}
		if (this.isPowerError()) {
			nbt.setBoolean("power", true);
		}
		return nbt;
	}

	public boolean isItemError() {
		return this.itemError;
	}

	public boolean isTankError() {
		return this.tankError;
	}

	public boolean isPowerError() {
		return this.powerError;
	}
}
